@@ -17,9 +17,10 @@ async def get_vote_info(vote_id: int):
     获取投票详情
 
     Args:
-        vote_id: vote_id,获取：nemo2011.github.io/bilibili-api/#/vote_id
+        vote_id (int): vote_id, 获取：nemo2011.github.io/bilibili-api/#/vote_id
+
     Returns:
-        调用 API 返回的结果
+        dict: 调用 API 返回的结果
     """
     api = API["vote"]["info"]["get_info"]
     params = {"vote_id": vote_id}
